%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Investment Judgment Advisor
%%% Programed by Jhiin Joo specifically for MAC users
%%% March 3, 2009
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function varargout = ShowResults_First(varargin)
% SHOWRESULTS_FIRST M-file for ShowResults_First.fig
%      SHOWRESULTS_FIRST, by itself, creates a new SHOWRESULTS_FIRST or raises the existing
%      singleton*.
%
%      H = SHOWRESULTS_FIRST returns the handle to a new SHOWRESULTS_FIRST or the handle to
%      the existing singleton*.
%
%      SHOWRESULTS_FIRST('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in SHOWRESULTS_FIRST.M with the given input arguments.
%
%      SHOWRESULTS_FIRST('Property','Value',...) creates a new SHOWRESULTS_FIRST or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before ShowResults_First_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to ShowResults_First_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help ShowResults_First

% Last Modified by GUIDE v2.5 20-Apr-2009 11:55:15

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @ShowResults_First_OpeningFcn, ...
                   'gui_OutputFcn',  @ShowResults_First_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before ShowResults_First is made visible.
function ShowResults_First_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to ShowResults_First (see VARARGIN)

global Xs Ws MFsf_nega
global counter Cs S
global xxs xxl xxr a
global xxsm xxsl xxsr

global XS1 WS1 XXS1 XXL1 XXR1 XXSM1 XXSL1 XXSR1
global ling1_11 ling1_12 ling1_13 ling1_14
global ling1_21 ling1_22 ling1_23 ling1_24
global ling1_31 ling1_32 ling1_33 ling1_34
global ling1_41 ling1_42 ling1_43 ling1_44
global ling1_51 ling1_52 ling1_53 ling1_54
global ling1_61 ling1_62 ling1_63 ling1_64
global rank1_1 rank1_2 rank1_3 rank1_4 rank1_5
global cen1_1 cen1_2 cen1_3 cen1_4 cen1_5
global sim1_11 sim1_12 sim1_13 sim1_14 sim1_15
global sim1_21 sim1_22 sim1_23 sim1_24 sim1_25
global sim1_31 sim1_32 sim1_33 sim1_34 sim1_35
global sim1_41 sim1_42 sim1_43 sim1_44 sim1_45
global sim1_51 sim1_52 sim1_53 sim1_54 sim1_55
global XS2 WS2 XXS2 XXL2 XXR2 XXSM2 XXSL2 XXSR2
global ling2_11 ling2_12 ling2_13 ling2_14
global ling2_21 ling2_22 ling2_23 ling2_24
global ling2_31 ling2_32 ling2_33 ling2_34
global ling2_41 ling2_42 ling2_43 ling2_44
global ling2_51 ling2_52 ling2_53 ling2_54
global ling2_61 ling2_62 ling2_63 ling2_64
global rank2_1 rank2_2 rank2_3 rank2_4 rank2_5
global cen2_1 cen2_2 cen2_3 cen2_4 cen2_5
global sim2_11 sim2_12 sim2_13 sim2_14 sim2_15
global sim2_21 sim2_22 sim2_23 sim2_24 sim2_25
global sim2_31 sim2_32 sim2_33 sim2_34 sim2_35
global sim2_41 sim2_42 sim2_43 sim2_44 sim2_45
global sim2_51 sim2_52 sim2_53 sim2_54 sim2_55

global XS3 WS3 XXS3 XXL3 XXR3 XXSM3 XXSL3 XXSR3
global ling3_11 ling3_12 ling3_13 ling3_14
global ling3_21 ling3_22 ling3_23 ling3_24
global ling3_31 ling3_32 ling3_33 ling3_34
global ling3_41 ling3_42 ling3_43 ling3_44
global ling3_51 ling3_52 ling3_53 ling3_54
global ling3_61 ling3_62 ling3_63 ling3_64
global rank3_1 rank3_2 rank3_3 rank3_4 rank3_5
global cen3_1 cen3_2 cen3_3 cen3_4 cen3_5
global sim3_11 sim3_12 sim3_13 sim3_14 sim3_15
global sim3_21 sim3_22 sim3_23 sim3_24 sim3_25
global sim3_31 sim3_32 sim3_33 sim3_34 sim3_35
global sim3_41 sim3_42 sim3_43 sim3_44 sim3_45
global sim3_51 sim3_52 sim3_53 sim3_54 sim3_55
%%Blank;
Results_counter1;
SaveParameters1;
% close(IJA);
clear Xs Ws Xs1 Xs2 Xs3 Xs4 Xs5
clear xxs xxl xxr a
clear xxsm xxsl xxsr

% Choose default command line output for ShowResults_First
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes ShowResults_First wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = ShowResults_First_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)



% Get default command line output from handles structure
varargout{1} = handles.output;


function edit1_11_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_11 as text
%        str2double(get(hObject,'String')) returns contents of edit1_11 as a double


% --- Executes during object creation, after setting all properties.
function edit1_11_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_12_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_12 as text
%        str2double(get(hObject,'String')) returns contents of edit1_12 as a double


% --- Executes during object creation, after setting all properties.
function edit1_12_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_13_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_13 as text
%        str2double(get(hObject,'String')) returns contents of edit1_13 as a double


% --- Executes during object creation, after setting all properties.
function edit1_13_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit4_Callback(hObject, eventdata, handles)
% hObject    handle to edit4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit4 as text
%        str2double(get(hObject,'String')) returns contents of edit4 as a double


% --- Executes during object creation, after setting all properties.
function edit4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_21_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_21 as text
%        str2double(get(hObject,'String')) returns contents of edit1_21 as a double


% --- Executes during object creation, after setting all properties.
function edit1_21_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_22_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_22 as text
%        str2double(get(hObject,'String')) returns contents of edit1_22 as a double


% --- Executes during object creation, after setting all properties.
function edit1_22_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_23_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_23 as text
%        str2double(get(hObject,'String')) returns contents of edit1_23 as a double


% --- Executes during object creation, after setting all properties.
function edit1_23_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_24_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_24 as text
%        str2double(get(hObject,'String')) returns contents of edit1_24 as a double


% --- Executes during object creation, after setting all properties.
function edit1_24_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_31_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_31 as text
%        str2double(get(hObject,'String')) returns contents of edit1_31 as a double


% --- Executes during object creation, after setting all properties.
function edit1_31_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_32_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_32 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_32 as text
%        str2double(get(hObject,'String')) returns contents of edit1_32 as a double


% --- Executes during object creation, after setting all properties.
function edit1_32_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_32 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_41_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_41 as text
%        str2double(get(hObject,'String')) returns contents of edit1_41 as a double


% --- Executes during object creation, after setting all properties.
function edit1_41_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_51_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_51 as text
%        str2double(get(hObject,'String')) returns contents of edit1_51 as a double


% --- Executes during object creation, after setting all properties.
function edit1_51_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_61_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_61 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_61 as text
%        str2double(get(hObject,'String')) returns contents of edit1_61 as a double


% --- Executes during object creation, after setting all properties.
function edit1_61_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_61 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_42_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_42 as text
%        str2double(get(hObject,'String')) returns contents of edit1_42 as a double


% --- Executes during object creation, after setting all properties.
function edit1_42_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_52_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_52 as text
%        str2double(get(hObject,'String')) returns contents of edit1_52 as a double


% --- Executes during object creation, after setting all properties.
function edit1_52_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_62_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_62 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_62 as text
%        str2double(get(hObject,'String')) returns contents of edit1_62 as a double


% --- Executes during object creation, after setting all properties.
function edit1_62_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_62 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_33_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_33 as text
%        str2double(get(hObject,'String')) returns contents of edit1_33 as a double


% --- Executes during object creation, after setting all properties.
function edit1_33_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_43_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_43 as text
%        str2double(get(hObject,'String')) returns contents of edit1_43 as a double


% --- Executes during object creation, after setting all properties.
function edit1_43_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_53_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_53 as text
%        str2double(get(hObject,'String')) returns contents of edit1_53 as a double


% --- Executes during object creation, after setting all properties.
function edit1_53_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_63_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_63 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_63 as text
%        str2double(get(hObject,'String')) returns contents of edit1_63 as a double


% --- Executes during object creation, after setting all properties.
function edit1_63_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_63 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_34_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_34 as text
%        str2double(get(hObject,'String')) returns contents of edit1_34 as a double


% --- Executes during object creation, after setting all properties.
function edit1_34_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_44_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_44 as text
%        str2double(get(hObject,'String')) returns contents of edit1_44 as a double


% --- Executes during object creation, after setting all properties.
function edit1_44_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_64_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_64 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_64 as text
%        str2double(get(hObject,'String')) returns contents of edit1_64 as a double


% --- Executes during object creation, after setting all properties.
function edit1_64_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_64 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_54_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_54 as text
%        str2double(get(hObject,'String')) returns contents of edit1_54 as a double


% --- Executes during object creation, after setting all properties.
function edit1_54_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_cen1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen1 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen1 as a double


% --- Executes during object creation, after setting all properties.
function edit1_cen1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_cen2_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen2 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen2 as a double


% --- Executes during object creation, after setting all properties.
function edit1_cen2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_rank3_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank3 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank3 as a double


% --- Executes during object creation, after setting all properties.
function edit1_rank3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_rank5_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank5 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank5 as a double


% --- Executes during object creation, after setting all properties.
function edit1_rank5_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit39_Callback(hObject, eventdata, handles)
% hObject    handle to edit39 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit39 as text
%        str2double(get(hObject,'String')) returns contents of edit39 as a double


% --- Executes during object creation, after setting all properties.
function edit39_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit39 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_cen4_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen4 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen4 as a double


% --- Executes during object creation, after setting all properties.
function edit1_cen4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_cen5_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen5 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen5 as a double


% --- Executes during object creation, after setting all properties.
function edit1_cen5_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_cen3_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_cen3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_cen3 as text
%        str2double(get(hObject,'String')) returns contents of edit1_cen3 as a double


% --- Executes during object creation, after setting all properties.
function edit1_cen3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_cen3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_rank1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank1 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank1 as a double


% --- Executes during object creation, after setting all properties.
function edit1_rank1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_rank2_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank2 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank2 as a double


% --- Executes during object creation, after setting all properties.
function edit1_rank2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim11_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim11 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim11 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim11_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim12_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim12 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim12 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim12_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim13_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim13 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim13 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim13_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim14_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim14 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim14 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim14_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim15_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim15 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim15 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim15_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim21_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim21 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim21 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim21_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim22_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim22 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim22 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim22_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim23_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim23 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim23 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim23_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit203_Callback(hObject, eventdata, handles)
% hObject    handle to edit203 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit203 as text
%        str2double(get(hObject,'String')) returns contents of edit203 as a double


% --- Executes during object creation, after setting all properties.
function edit203_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit203 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim25_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim25 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim25 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim25 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim25_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim25 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim31_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim31 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim31 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim31_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim32_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim32 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim32 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim32 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim32_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim32 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim33_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim33 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim33 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim33_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim34_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim34 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim34 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim34_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim35_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim35 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim35 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim35 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim35_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim35 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim41_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim41 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim41 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim41_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim51_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim51 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim51 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim51_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim51 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim42_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim42 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim42 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim42_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim43_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim43 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim43 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim43_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim44_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim44 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim44 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim44_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim45_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim45 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim45 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim45 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim45_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim45 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim52_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim52 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim52 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim52_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim52 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim53_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim53 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim53 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim53_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim53 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim54_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim54 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim54 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim54_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim54 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim55_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim55 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim55 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim55 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim55_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim55 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_14_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_14 as text
%        str2double(get(hObject,'String')) returns contents of edit1_14 as a double


% --- Executes during object creation, after setting all properties.
function edit1_14_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_rank4_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_rank4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_rank4 as text
%        str2double(get(hObject,'String')) returns contents of edit1_rank4 as a double


% --- Executes during object creation, after setting all properties.
function edit1_rank4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_rank4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_sim24_Callback(hObject, eventdata, handles)
% hObject    handle to edit1_sim24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1_sim24 as text
%        str2double(get(hObject,'String')) returns contents of edit1_sim24 as a double


% --- Executes during object creation, after setting all properties.
function edit1_sim24_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1_sim24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end




% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
close all;
IJA;



% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


close all;
IJA_demo;